# semlib

::: semlib
    options:
      # explicit list so we can choose order, putting Session first
      members: [Session, QueryCache, OnDiskCache, InMemoryCache, Bare, Box]
:::
<!-- https://github.com/danielfrg/mkdocs-jupyter/issues/231 -->
